==> Botania-1.19.2-438-FABRIC-20230214.034242-11-sources.jar: vazkii/botania/client/render/block_entity/CorporeaIndexBlockEntityRenderer.java <==
/*
 * This class is distributed as part of the Botania Mod.
 * Get the Source Code in github:
 * https://github.com/Vazkii/Botania
 *
 * Botania is Open Source and distributed under the
 * Botania License: http://botaniamod.net/license.php
 */
package vazkii.botania.client.render.block_entity;

import net.minecraft.class_1158;
import net.minecraft.class_1160;
import net.minecraft.class_1921;
import net.minecraft.class_2960;
import net.minecraft.class_4587;
import net.minecraft.class_4588;
import net.minecraft.class_4597;
import net.minecraft.class_5603;
import net.minecraft.class_5606;
import net.minecraft.class_5609;
import net.minecraft.class_5610;
import net.minecraft.class_5614;
import net.minecraft.class_630;
import net.minecraft.class_827;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import vazkii.botania.client.core.handler.ClientTickHandler;
import vazkii.botania.client.core.helper.RenderHelper;
import vazkii.botania.client.lib.ResourcesLib;
import vazkii.botania.client.model.BotaniaModelLayers;
import vazkii.botania.common.block.block_entity.corporea.CorporeaIndexBlockEntity;

public class CorporeaIndexBlockEntityRenderer implements class_827<CorporeaIndexBlockEntity> {
	private static final class_1921 LAYER = class_1921.method_23578(new class_2960(ResourcesLib.MODEL_CORPOREA_INDEX));
	private static final float ANGLE = (float) Math.sin(Math.toRadians(45));
	private final class_630 ring;
	private final class_630 cube;

	public CorporeaIndexBlockEntityRenderer(class_5614.class_5615 ctx) {
		class_630 root = ctx.method_32140(BotaniaModelLayers.CORPOREA_INDEX);
		this.ring = root.method_32086("ring");
		this.cube = root.method_32086("cube");
	}

	public static class_5609 createMesh() {
		var mesh = new class_5609();
		var root = mesh.method_32111();
		root.method_32117("ring", class_5606.method_32108()
				.method_32097(-4.0F, -4.0F, -4.0F, 8.0F, 8.0F, 8.0F),
				class_5603.field_27701);
		root.method_32117("cube", class_5606.method_32108().method_32101(32, 0)
				.method_32097(-4.0F, -4.0F, -4.0F, 8.0F, 8.0F, 8.0F),
				class_5603.field_27701);
		return mesh;
	}

	@Override
	public boolean shouldRenderOffScreen(@NotNull CorporeaIndexBlockEntity blockEntity) {
		return true;
	}

	@Override
	public void render(@Nullable CorporeaIndexBlockEntity index, float partialTicks, class_4587 ms, class_4597 buffers, int light, int overlay) {
		ms.method_22903();
		ms.method_22904(0.5, 0, 0.5);

		float rotation = (ClientTickHandler.ticksInGame + partialTicks) * 2;
		float translation;
		if (index == null) { // Item render
			ms.method_22905(1.3f, 1.3f, 1.3f);
			ms.method_22904(0, -0.1, 0);
			translation = 0;
		} else {
			translation = (float) ((Math.cos((index.ticksWithCloseby + (index.hasCloseby ? partialTicks : 0)) / 10F) * 0.5 + 0.5) * 0.25);
		}

		class_4588 buffer = buffers.getBuffer(LAYER);
		ms.method_22903();
		ms.method_22904(0.0D, -1, 0.0D);

		ms.method_22907(class_1160.field_20705.method_23214(rotation));
		ms.method_22904(0.0D, 1.5F + translation / 2.0F, 0.0D);
		ms.method_22907(new class_1158(new class_1160(ANGLE, 0.0F, ANGLE), 60.0F, true));
		this.ring.method_22698(ms, buffer, light, overlay);
		ms.method_22905(0.875F, 0.875F, 0.875F);
		ms.method_22907(new class_1158(new class_1160(ANGLE, 0.0F, ANGLE), 60.0F, true));
		ms.method_22907(class_1160.field_20705.method_23214(rotation));
		this.ring.method_22698(ms, buffer, light, overlay);
		ms.method_22905(0.875F, 0.875F, 0.875F);
		ms.method_22907(new class_1158(new class_1160(ANGLE, 0.0F, ANGLE), 60.0F, true));
		ms.method_22907(class_1160.field_20705.method_23214(rotation));
		this.cube.method_22698(ms, buffer, light, overlay);
		ms.method_22909();

		if (index != null && index.closeby > 0F) {
			float starScale = 0.02F;
			float starRadius = (float) CorporeaIndexBlockEntity.RADIUS * index.closeby + (index.closeby == 1F ? 0F : index.hasCloseby ? partialTicks : -partialTicks) * 0.2F;
			double rads = (index.ticksWithCloseby + partialTicks) * 2 * Math.PI / 180;
			double starX = Math.cos(rads) * starRadius;
			double starZ = Math.sin(rads) * starRadius;
			int color = 0xFF00FF;
			int seed = index.method_11016().method_10263() ^ index.method_11016().method_10264() ^ index.method_11016().method_10260();

			ms.method_22904(starX, 0.3, starZ);
			RenderHelper.renderStar(ms, buffers, color, starScale, starScale, starScale, seed);
			ms.method_22904(-starX * 2, 0, -starZ * 2);
			RenderHelper.renderStar(ms, buffers, color, starScale, starScale, starScale, seed);
			ms.method_22904(starX, 0, starZ);

			rads = -rads;
			starX = Math.cos(rads) * starRadius;
			starZ = Math.sin(rads) * starRadius;
			ms.method_22904(starX, 0, starZ);
			RenderHelper.renderStar(ms, buffers, color, starScale, starScale, starScale, seed);
			ms.method_22904(-starX * 2, 0, -starZ * 2);
			RenderHelper.renderStar(ms, buffers, color, starScale, starScale, starScale, seed);
			ms.method_22904(starX, 0, starZ);
		}
		ms.method_22909();
	}

}

==> Botania-1.20.1-451-FABRIC-20251214.151426-36-sources.jar: vazkii/botania/client/render/block_entity/CorporeaIndexBlockEntityRenderer.java <==
/*
 * This class is distributed as part of the Botania Mod.
 * Get the Source Code in github:
 * https://github.com/Vazkii/Botania
 *
 * Botania is Open Source and distributed under the
 * Botania License: http://botaniamod.net/license.php
 */
package vazkii.botania.client.render.block_entity;

import net.minecraft.class_1921;
import net.minecraft.class_2960;
import net.minecraft.class_4587;
import net.minecraft.class_4588;
import net.minecraft.class_4597;
import net.minecraft.class_5603;
import net.minecraft.class_5606;
import net.minecraft.class_5609;
import net.minecraft.class_5610;
import net.minecraft.class_5614;
import net.minecraft.class_630;
import net.minecraft.class_827;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;
import org.joml.Quaternionf;

import vazkii.botania.client.core.handler.ClientTickHandler;
import vazkii.botania.client.core.helper.RenderHelper;
import vazkii.botania.client.lib.ResourcesLib;
import vazkii.botania.client.model.BotaniaModelLayers;
import vazkii.botania.common.block.block_entity.corporea.CorporeaIndexBlockEntity;
import vazkii.botania.common.helper.VecHelper;

public class CorporeaIndexBlockEntityRenderer implements class_827<CorporeaIndexBlockEntity> {
	private static final class_1921 LAYER = class_1921.method_23578(new class_2960(ResourcesLib.MODEL_CORPOREA_INDEX));
	private static final float ANGLE = (float) Math.sin(Math.toRadians(45));
	private final class_630 ring;
	private final class_630 cube;

	public CorporeaIndexBlockEntityRenderer(class_5614.class_5615 ctx) {
		class_630 root = ctx.method_32140(BotaniaModelLayers.CORPOREA_INDEX);
		this.ring = root.method_32086("ring");
		this.cube = root.method_32086("cube");
	}

	public static class_5609 createMesh() {
		var mesh = new class_5609();
		var root = mesh.method_32111();
		root.method_32117("ring", class_5606.method_32108()
				.method_32097(-4.0F, -4.0F, -4.0F, 8.0F, 8.0F, 8.0F),
				class_5603.field_27701);
		root.method_32117("cube", class_5606.method_32108().method_32101(32, 0)
				.method_32097(-4.0F, -4.0F, -4.0F, 8.0F, 8.0F, 8.0F),
				class_5603.field_27701);
		return mesh;
	}

	@Override
	public boolean shouldRenderOffScreen(@NotNull CorporeaIndexBlockEntity blockEntity) {
		return true;
	}

	@Override
	public void render(@Nullable CorporeaIndexBlockEntity index, float partialTicks, class_4587 ms, class_4597 buffers, int light, int overlay) {
		ms.method_22903();
		ms.method_22904(0.5, 0, 0.5);

		float rotation = (ClientTickHandler.ticksInGame + partialTicks) * 2;
		float translation;
		if (index == null) { // Item render
			ms.method_22905(1.3f, 1.3f, 1.3f);
			ms.method_22904(0, -0.1, 0);
			translation = 0;
		} else {
			translation = (float) ((Math.cos((index.ticksWithCloseby + (index.hasCloseby ? partialTicks : 0)) / 10F) * 0.5 + 0.5) * 0.25);
		}

		class_4588 buffer = buffers.getBuffer(LAYER);
		ms.method_22903();
		ms.method_22904(0.0D, -1, 0.0D);

		ms.method_22907(VecHelper.rotateY(rotation));
		ms.method_22904(0.0D, 1.5F + translation / 2.0F, 0.0D);
		ms.method_22907(new Quaternionf().rotateAxis(VecHelper.toRadians(60.0F), ANGLE, 0.0F, ANGLE));
		this.ring.method_22698(ms, buffer, light, overlay);
		ms.method_22905(0.875F, 0.875F, 0.875F);
		ms.method_22907(new Quaternionf().rotateAxis(VecHelper.toRadians(60.0F), ANGLE, 0.0F, ANGLE));
		ms.method_22907(VecHelper.rotateY(rotation));
		this.ring.method_22698(ms, buffer, light, overlay);
		ms.method_22905(0.875F, 0.875F, 0.875F);
		ms.method_22907(new Quaternionf().rotateAxis(VecHelper.toRadians(60.0F), ANGLE, 0.0F, ANGLE));
		ms.method_22907(VecHelper.rotateY(rotation));
		this.cube.method_22698(ms, buffer, light, overlay);
		ms.method_22909();

		if (index != null && index.closeby > 0F) {
			float starScale = 0.02F;
			float starRadius = (float) CorporeaIndexBlockEntity.RADIUS * index.closeby + (index.closeby == 1F ? 0F : index.hasCloseby ? partialTicks : -partialTicks) * 0.2F;
			double rads = (index.ticksWithCloseby + partialTicks) * 2 * Math.PI / 180;
			double starX = Math.cos(rads) * starRadius;
			double starZ = Math.sin(rads) * starRadius;
			int color = 0xFF00FF;
			int seed = index.method_11016().method_10263() ^ index.method_11016().method_10264() ^ index.method_11016().method_10260();

			ms.method_22904(starX, 0.3, starZ);
			RenderHelper.renderStar(ms, buffers, color, starScale, starScale, starScale, seed);
			ms.method_22904(-starX * 2, 0, -starZ * 2);
			RenderHelper.renderStar(ms, buffers, color, starScale, starScale, starScale, seed);
			ms.method_22904(starX, 0, starZ);

			rads = -rads;
			starX = Math.cos(rads) * starRadius;
			starZ = Math.sin(rads) * starRadius;
			ms.method_22904(starX, 0, starZ);
			RenderHelper.renderStar(ms, buffers, color, starScale, starScale, starScale, seed);
			ms.method_22904(-starX * 2, 0, -starZ * 2);
			RenderHelper.renderStar(ms, buffers, color, starScale, starScale, starScale, seed);
			ms.method_22904(starX, 0, starZ);
		}
		ms.method_22909();
	}

}
